libhasher
A simple library for hashing files and text with a variety of algorithms, including non-cryptographic ones.
It also supports progress bars for large files and the ability to use Blake3’s mmap feature for even faster hashing of large files.
Structs
- Hash
Result - The result of hashing a file
- Hasher
- A dynamic Hasher struct to handle all supported algorithms
Traits
- DynHasher
- Trait to allow for dynamic dispatch of different hashers.
This is necessary because the
Digesttrait does not support dynamic dispatch, and we want to be able to use different hash algorithms with the same interface.